@@ -279,7 +279,10 @@ class Measurement:
                 chronological_measurement_centile = None
             try:
                 chronological_centile_band = centile_band_for_centile(
-                    sds=chronological_measurement_sds, measurement_method=measurement_method)
+                    sds=chronological_measurement_sds, 
+                    measurement_method=measurement_method,
+                    centile_format=COLE_TWO_THIRDS_SDS_NINE_CENTILES
+                    )
             except TypeError as err:
                 chronological_measurement_error = "Not possible to calculate centile"
                 chronological_centile_band = None
@@ -298,7 +301,10 @@ class Measurement:
 
             try:
                 corrected_centile_band = centile_band_for_centile(
-                    sds=corrected_measurement_sds, measurement_method=measurement_method)
+                    sds=corrected_measurement_sds, 
+                    measurement_method=measurement_method,
+                    centile_format=COLE_TWO_THIRDS_SDS_NINE_CENTILES
+                )
             except TypeError as err:
                 corrected_measurement_error = "Not possible to calculate centile"
                 corrected_centile_band = None
